==> worksdata-0.0.4.tar.gz: lib/services/api_service.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:collection/collection.dart';
import 'package:http/http.dart' as http;
import 'package:retry/retry.dart';
import 'package:worksdata/services/api.dart';

class ApiService {
  ApiService({this.api});

  final API api;

  Future<dynamic> get(String path,
      {Map queryParameters, Map<String, String> header}) async {
    var finalUrl = api.endpointUrl(path);
    var responseJson;
    if (queryParameters != null) {
      queryParameters.forEach((k, v) {
        finalUrl += !finalUrl.contains('?') ? '?$k=$v' : '&$k=$v';
      });
    }
    try {
      final response = await retry(
          () => http.get(finalUrl, headers: header ?? {}),
          retryIf: (e) => e is SocketException || e is TimeoutException);
      responseJson = _response(response);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    } on TimeoutException {
      throw FetchDataException('Connection Timeout');
    } catch (e) {
      throw FetchDataException('Unhandled Exception : ${e.toString()}');
    }
    return responseJson;
  }

  Future<dynamic> post(String path,
      {Map body, Map<String, String> header}) async {
    var responseJson;
    try {
      final response = await retry(
          () => http.post(
                api.endpointUrl(path),
                headers: mergeMaps({
                  'Content-type': 'application/json',
                }, (header ?? {})),
                body: json.encode(body),
              ),
          retryIf: (e) => e is SocketException || e is TimeoutException);
      responseJson = _response(response);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    } on TimeoutException {
      throw FetchDataException('Connection Timeout');
    } catch (e) {
      throw FetchDataException('Unhandled Exception : ${e.toString()}');
    }
    return responseJson;
  }

  dynamic _response(http.Response response) {
    switch (response.statusCode) {
      case 200:
      case 201:
        var responseJson = json.decode(response.body);
        return responseJson;
      case 400:
        throw BadRequestException(response.body.toString());
      case 401:
      case 403:
        throw UnauthorisedException(response.body.toString());
      case 500:
      default:
        throw FetchDataException(
            'Error occured while Communication with Server with StatusCode : ${response.statusCode}');
    }
  }
}

class CustomException implements Exception {
  final _message;
  final _prefix;

  CustomException([this._message, this._prefix]);

  @override
  String toString() {
    return '$_prefix$_message';
  }
}

class FetchDataException extends CustomException {
  FetchDataException([String message])
      : super(message, 'Error During Communication: ');
}

class BadRequestException extends CustomException {
  BadRequestException([message]) : super(message, 'Invalid Request: ');
}

class UnauthorisedException extends CustomException {
  UnauthorisedException([message]) : super(message, 'Unauthorised: ');
}

class InvalidInputException extends CustomException {
  InvalidInputException([String message]) : super(message, 'Invalid Input: ');
}

==> worksdata-0.0.6.tar.gz: lib/services/api_service.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:collection/collection.dart';
import 'package:http/http.dart' as http;
import 'package:retry/retry.dart';
import 'package:worksdata/services/api.dart';

class ApiService {
  ApiService({this.api});

  final API api;

  /// Make 'get' http call.
  ///
  ///
  Future<dynamic> get(String path,
      {Map queryParameters, Map<String, String> header}) async {
    var finalUrl = api.endpointUrl(path);
    var responseJson;
    if (queryParameters != null) {
      queryParameters.forEach((k, v) {
        finalUrl += !finalUrl.contains('?') ? '?$k=$v' : '&$k=$v';
      });
    }
    try {
      final response = await retry(
          () => http.get(Uri.parse(finalUrl), headers: header ?? {}),
          retryIf: (e) => e is SocketException || e is TimeoutException);
      responseJson = _response(response);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    } on TimeoutException {
      throw FetchDataException('Connection Timeout');
    } catch (e) {
      throw FetchDataException('Unhandled Exception : ${e.toString()}');
    }
    return responseJson;
  }

  Future<dynamic> post(String path,
      {Map body, Map<String, String> header}) async {
    var responseJson;
    try {
      final response = await retry(
          () => http.post(
                Uri.parse(api.endpointUrl(path)),
                headers: mergeMaps({
                  'Content-type': 'application/json',
                }, (header ?? {})),
                body: json.encode(body),
              ),
          retryIf: (e) => e is SocketException || e is TimeoutException);
      responseJson = _response(response);
    } on SocketException {
      throw FetchDataException('No Internet connection');
    } on TimeoutException {
      throw FetchDataException('Connection Timeout');
    } catch (e) {
      throw FetchDataException('Unhandled Exception : ${e.toString()}');
    }
    return responseJson;
  }

  dynamic _response(http.Response response) {
    switch (response.statusCode) {
      case 200:
      case 201:
        var responseJson = json.decode(response.body);
        return responseJson;
      case 400:
        throw BadRequestException(response.body.toString());
      case 401:
      case 403:
        throw UnauthorisedException(response.body.toString());
      case 500:
      default:
        throw FetchDataException(
            'Error occured while Communication with Server with StatusCode : ${response.statusCode}');
    }
  }
}

class CustomException implements Exception {
  final _message;
  final _prefix;

  CustomException([this._message, this._prefix]);

  @override
  String toString() {
    return '$_prefix$_message';
  }
}

class FetchDataException extends CustomException {
  FetchDataException([String message])
      : super(message, 'Error During Communication: ');
}

class BadRequestException extends CustomException {
  BadRequestException([message]) : super(message, 'Invalid Request: ');
}

class UnauthorisedException extends CustomException {
  UnauthorisedException([message]) : super(message, 'Unauthorised: ');
}

class InvalidInputException extends CustomException {
  InvalidInputException([String message]) : super(message, 'Invalid Input: ');
}
